@@ -1,9 +1,5 @@
 """Module for book-keeping and aggregation of ensembles"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import re
 import os
 import glob
