@@ -2,10 +2,6 @@
 Observations support and related calculations
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import math
 import datetime
