@@ -7,10 +7,6 @@ it can be computed from other realizations, or it can be
 an archived realization.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import re
 import copy
