@@ -1,8 +1,4 @@
 """Contains the VirtualRealization class"""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import fnmatch
 import shutil
