@@ -1,10 +1,6 @@
 """Testing fmu-ensemble."""
 # pylint: disable=protected-access
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 
 import yaml
