@@ -1,9 +1,5 @@
 """Testing fmu-ensemble, virtualized ensembles"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 from datetime import datetime
 import numpy as np
